<?php
//=================================================================
// KOOBI R7 - CMS - PORTALSOFTWARE(c) DREAM4(r) 
// HTTP://WWW.DREAM4.DE
//=================================================================
// ACHTUNG!
// DIESER PROGRAMMCODE IST URHERRECHTLICH GESCHUETZT
// DIE URHEBERRECHTE LIEGEN BEI DEN JEWEILIGEN AUTOREN.
// AENDERUNGEN IN DIESER DATEI ERFOLGEN AUF EIGENE GEFAHR!
// ES IST NICHT GESTATTET, DEN COPYRIGHTHINWEIS ZU AENDERN ODER ZU
// ENTFERNEN. NUR WENN SIE EINE COPYRIGHTHINWEIS-ENTFERNUNG BESTELLT
// HABEN, DUERFEN SIE DIESEN ENTFERNEN.
//================================================================
// BEI FRAGEN WENDEN SIE SICH BITTE AN: KONTAKT@DREAM4.DE
//=================================================================
if(!defined('BASE_DIR')) exit;


if(!get_active('links') || @!file_exists(BASE_DIR . '/class/Class.Links.php'))
{
	notActive();
} else {
	if(!permission('links'))
	{
		noperm();
	} else {
		
		include_once(BASE_DIR . '/class/Class.Links.php');
		$Links = new Links;
		$Links->Settings();
		
		$_REQUEST['action'] = isset($_REQUEST['action']) ? $_REQUEST['action'] : '';
		switch($_REQUEST['action'])
		{
			case '':
				$Links->displayCategs();
			break;
			
			case 'search':
				$Links->SearchLinks();
			break;
			
			case 'brokenlink':
				define('AJAX_OUTPUT',1);
				$Links->BrokenLink(@$_REQUEST['id']);
			break;
			
			case 'showdetails':
				$Links->showDetails(@$_REQUEST['id']);
			break;
			
			case 'updatehitcount':
				define('AJAX_OUTPUT',1);
				$Links->Updatehitcount(@$_REQUEST['id']);
			break;
		}
		
		
	}
}
?>